@@ -7,7 +7,8 @@ use warnings;
 use Module::Load;
 use SHARYANTO::Package::Util qw(package_exists);
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
+our $DATE = '2014-05-02'; # DATE
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -252,11 +253,7 @@ Data::Unixish - Implementation for Unixish, a data transformation framework
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 SYNOPSIS
 
