@@ -1,6 +1,6 @@
 package Data::Unixish::Util;
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -39,11 +39,7 @@ Data::Unixish::Util - Utility routines
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish::Util (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 EXPORTS
 
