@@ -9,7 +9,7 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
 
 our %SPEC;
 
@@ -53,11 +53,7 @@ Data::Unixish::avg - Average numbers
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish::avg (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 SYNOPSIS
 
