@@ -9,7 +9,7 @@ use Scalar::Util 'looks_like_number';
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
 
 our %SPEC;
 
@@ -49,11 +49,7 @@ Data::Unixish::sum - Sum numbers
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish::sum (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 SYNOPSIS
 
