@@ -11,7 +11,7 @@ use Data::Unixish::Util qw(%common_args);
 use Text::ANSI::Util qw(ta_trunc ta_mbtrunc);
 use Text::WideChar::Util qw(mbtrunc);
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
 
 our %SPEC;
 
@@ -88,11 +88,7 @@ Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 SYNOPSIS
 
