@@ -10,7 +10,7 @@ use Data::Unixish::Util qw(%common_args);
 use Text::ANSI::Util qw(ta_wrap ta_mbwrap);
 use Text::WideChar::Util qw(mbwrap);
 
-our $VERSION = '1.44'; # VERSION
+our $VERSION = '1.45'; # VERSION
 
 our %SPEC;
 
@@ -87,11 +87,7 @@ Data::Unixish::wrap - Wrap text
 
 =head1 VERSION
 
-version 1.44
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 1.45 of Data::Unixish::wrap (from Perl distribution Data-Unixish), released on 2014-05-02.
 
 =head1 SYNOPSIS
 
